@@ -70,14 +70,17 @@ void KrBookmarkHandler::addBookmark(KrBookmark *bm, KrBookmark *folder) {
 	exportToFile();
 }
 
-void KrBookmarkHandler::deleteBookmark(KrBookmark *bm) {
+void KrBookmarkHandler::deleteBookmark(KrBookmark */*bm*/) {
 }
 
 void KrBookmarkHandler::exportToFileBookmark(QDomDocument &doc, QDomElement &where, KrBookmark *bm) {
 	QDomElement bookmark = doc.createElement("bookmark");
+	// url
 	bookmark.setAttribute("href", bm->url().url());
+	// icon
+	bookmark.setAttribute("icon", bm->icon());
 	// title
-	QDomElement title = doc.createElement("title");
+	QDomElement title = doc.createElement("title");	
 	title.appendChild(doc.createTextNode(bm->text()));
 	bookmark.appendChild(title);
 
@@ -88,6 +91,7 @@ void KrBookmarkHandler::exportToFileFolder(QDomDocument &doc, QDomElement &paren
 	for (KrBookmark *bm = folder->children().first(); bm; bm = folder->children().next()) {
 		if (bm->isFolder()) {
 			QDomElement newFolder = doc.createElement("folder");
+			newFolder.setAttribute("icon", bm->icon());
 			parent.appendChild(newFolder);
 			QDomElement title = doc.createElement("title");
 			title.appendChild(doc.createTextNode(bm->text()));
@@ -131,7 +135,7 @@ void KrBookmarkHandler::exportToFile() {
 	}
 }
 
-bool KrBookmarkHandler::importFromFileBookmark(QDomElement &e, KrBookmark *parent, QString *errorMsg) {
+bool KrBookmarkHandler::importFromFileBookmark(QDomElement &e, KrBookmark *parent, QString path, QString *errorMsg) {
 	QString url, name, icon;
 	// verify tag
 	if (e.tagName() != "bookmark") {
@@ -153,36 +157,38 @@ bool KrBookmarkHandler::importFromFileBookmark(QDomElement &e, KrBookmark *paren
 	if (e.hasAttribute("icon")) {
 		icon=e.attribute("icon");
 	}
-	
 	// ok: got name and url, let's add a bookmark
-	KrBookmark *bm = KrBookmark::getExistingBookmark(name, _collection);
-	if (!bm) 
-		bm = new KrBookmark(name, vfs::fromPathOrURL( url ), _collection, icon);
+	KrBookmark *bm = KrBookmark::getExistingBookmark(path+name, _collection);
+	if (!bm) {
+		bm = new KrBookmark(name, vfs::fromPathOrURL( url ), _collection, icon, path+name);
 	parent->children().append(bm);
+	}
 
 	return true;
 }
 
-bool KrBookmarkHandler::importFromFileFolder(QDomNode &first, KrBookmark *parent, QString *errorMsg) {
+bool KrBookmarkHandler::importFromFileFolder(QDomNode &first, KrBookmark *parent, QString path, QString *errorMsg) {
 	QString name;
 	QDomNode n = first;
 	while (!n.isNull()) {
 		QDomElement e = n.toElement();
 		if (e.tagName() == "bookmark") {
-			if (!importFromFileBookmark(e, parent, errorMsg))
+			if (!importFromFileBookmark(e, parent, path, errorMsg))
 				return false;
 		} else if (e.tagName() == "folder") {
+			QString iconName = "";
+			if (e.hasAttribute("icon")) iconName=e.attribute("icon");
 			// the title is the first child of the folder
 			QDomElement tmp = e.firstChild().toElement();
 			if (tmp.tagName() != "title") {
 				*errorMsg = i18n("missing tag ")+"title";
 				return false;
 			} else name = tmp.text();
-			KrBookmark *folder = new KrBookmark(name);
+			KrBookmark *folder = new KrBookmark(name, iconName);
 			parent->children().append(folder);
 
 			QDomNode nextOne = tmp.nextSibling();
-			if (!importFromFileFolder(nextOne, folder, errorMsg))
+			if (!importFromFileFolder(nextOne, folder, path + name + "/", errorMsg))
 				return false;
 		} else if (e.tagName() == "separator") {
 			parent->children().append(KrBookmark::separator());
@@ -217,7 +223,7 @@ void KrBookmarkHandler::importFromFile() {
 		errorMsg = filename+i18n(" doesn't seem to be a valid Bookmarks file");
 		goto ERROR;
 	} else n = n.firstChild(); // skip the xbel part
-	importFromFileFolder(n, _root, &errorMsg);
+	importFromFileFolder(n, _root, "", &errorMsg);
 	goto SUCCESS;
 	
 ERROR:
@@ -234,27 +240,35 @@ void KrBookmarkHandler::populate(KPopupMenu *menu) {
 
 void KrBookmarkHandler::buildMenu(KrBookmark *parent, KPopupMenu *menu) {
 	static int inSecondaryMenu = 0; // used to know if we're on the top menu
-	int floc=0, bloc=0;
-	
+
+	// run the loop twice, in order to put the folders on top. stupid but easy :-)
+	// note: this code drops the separators put there by the user
+	for (KrBookmark *bm = parent->children().first(); bm; bm = parent->children().next()) {
+		if (!bm->isFolder()) continue;
+		KPopupMenu *newMenu = new KPopupMenu(menu);
+		menu->insertItem(QIconSet(krLoader->loadIcon(bm->icon(), KIcon::Small)),
+									bm->text(), newMenu, -1 /* dummy id */, -1 /* end of list */);
+		++inSecondaryMenu;
+		buildMenu(bm, newMenu);
+		--inSecondaryMenu;
+	}
+	for (KrBookmark *bm = parent->children().first(); bm; bm = parent->children().next()) {
+		if (bm->isFolder()) continue;
+		if (bm->isSeparator() ) {
+			menu->insertSeparator();
+			continue;
+		}
+		bm->plug(menu, -1 /* end of list */);
+		CONNECT_BM(bm);
+	}
+
 	if (!inSecondaryMenu) {
-		// do we need to add special bookmarks?
-		if (SPECIAL_BOOKMARKS) {
-			// note: special bookmarks are not kept inside the _bookmarks list and added ad-hoc
-			KrBookmark *bm = KrBookmark::devices(_collection);
-			bm->plug(menu);
-			CONNECT_BM(bm);
-			bm = KrBookmark::lan(_collection);
-			bm->plug(menu);
-			CONNECT_BM(bm);
-			bm = KrBookmark::virt(_collection);
-			bm->plug(menu);
-			CONNECT_BM(bm);
-			floc = bloc = 3; // 3 bookmarks
-		} 
+		menu->insertSeparator();
+		
 		// add the popular links submenu
 		KPopupMenu *newMenu = new KPopupMenu(menu);
 		menu->insertItem(QIconSet(krLoader->loadIcon("bookmark_folder", KIcon::Small)),
-									i18n("Popular URLs"), newMenu, -1 /* dummy id */, floc);
+									i18n("Popular URLs"), newMenu, -1 /* dummy id */, -1 /* end of list */);
 		// add the top 15 urls
 		#define MAX 15
 		KURL::List list = krApp->popularUrls->getMostPopularUrls(MAX);
@@ -274,32 +288,26 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, KPopupMenu *menu) {
 		newMenu->insertSeparator();
 		krPopularUrls->plug(newMenu);
 		newMenu->installEventFilter(this);
+		menu->insertSeparator();
 		
-		// finished with popular links
-		menu->insertSeparator();
-		floc += 2; bloc +=2; // 1 group + separator
-	}
-
-	for (KrBookmark *bm = parent->children().first(); bm; bm = parent->children().next()) {
-		if (bm->isSeparator()) { // separator
-			menu->insertSeparator(bloc++);
-		} else if (bm->isFolder()) {
-			KPopupMenu *newMenu = new KPopupMenu(menu);
-			// add folders above bookmarks
-			menu->insertItem(QIconSet(krLoader->loadIcon("bookmark_folder", KIcon::Small)),
-									bm->text(), newMenu, -1 /* dummy id */, floc++);
-			++bloc; // stuffed a folder in the middle
-			++inSecondaryMenu;
-			buildMenu(bm, newMenu);
-			--inSecondaryMenu;
-		} else { // ordinary bookmark
-			bm->plug(menu, bloc++);
+		// do we need to add special bookmarks?
+		if (SPECIAL_BOOKMARKS) {
+			// note: special bookmarks are not kept inside the _bookmarks list and added ad-hoc
+			KrBookmark *bm = KrBookmark::devices(_collection);
+			bm->plug(menu);
 			CONNECT_BM(bm);
-		}
-	}
-
-	if (!inSecondaryMenu) {
+			bm = KrBookmark::lan(_collection);
+			bm->plug(menu);
+			CONNECT_BM(bm);
+			bm = KrBookmark::virt(_collection);
+			bm->plug(menu);
+			CONNECT_BM(bm);
+		} 
+		
+		// add the jump-back button
+		krJumpBack->plug(menu);
 		menu->insertSeparator();
+		krSetJumpBack->plug(menu);
 		menu->insertItem(krLoader->loadIcon("bookmark_add", KIcon::Small),
 			i18n("Bookmark Current"), BookmarkCurrent);
 		menu->insertItem(krLoader->loadIcon("bookmark", KIcon::Small),
@@ -313,13 +321,15 @@ void KrBookmarkHandler::buildMenu(KrBookmark *parent, KPopupMenu *menu) {
 	menu->installEventFilter(this);
 }
 
-
 void KrBookmarkHandler::clearBookmarks(KrBookmark *root) {
 	KrBookmark *bm = root->children().first();
 	while (bm) {	
 		if (bm->isFolder())
 			clearBookmarks(bm);
-		else bm->unplugAll();
+		else {
+			bm->unplugAll();
+			delete bm;
+		}
 
 		bm = root->children().next();
 	}
