@@ -51,12 +51,15 @@ A
 #include <qfileinfo.h>
 #include <sys/param.h>
 
-// use of version of it until kde fixes theirs
-#include "kdiskfreesp.h"
-
-
-
+#if defined(BSD)
+#include <kmountpoint.h>
+#include <kmdcodec.h>
+#else
 #define MTAB	"/etc/mtab"
+#endif
+
+// use our version of it until kde fixes theirs
+#include "kdiskfreesp.h"
 
 KMountManGUI::KMountManGUI() : KDialogBase( krApp, 0, true, "Mount.Man" ),
 info( 0 ), mountList( 0 ) {
@@ -78,8 +81,8 @@ info( 0 ), mountList( 0 ) {
    // connections
    connect( mountList, SIGNAL( doubleClicked( QListViewItem * ) ), this,
             SLOT( doubleClicked( QListViewItem* ) ) );
-   connect( mountList, SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int ) ),
-            this, SLOT( clicked( QListViewItem* ) ) );
+   connect( mountList, SIGNAL( contextMenuRequested( QListViewItem *, const QPoint &, int ) ),
+            this, SLOT( clicked( QListViewItem*, const QPoint&, int ) ) );
    connect( mountList, SIGNAL( clicked( QListViewItem * ) ), this,
             SLOT( changeActive( QListViewItem * ) ) );
    connect( mountList, SIGNAL( selectionChanged( QListViewItem * ) ), this,
@@ -145,7 +148,7 @@ void KMountManGUI::createMainPage() {
 
 void KMountManGUI::getSpaceData() {
    fileSystems.clear();
-	lastMtab = QFileInfo(MTAB).lastModified();
+	KrMountDetector::getInstance()->hasMountsChanged();
 	
    mounted = KMountPoint::currentMountPoints();
 	possible = KMountPoint::possibleMountPoints();
@@ -177,7 +180,7 @@ void KMountManGUI::gettingSpaceData() {
 }
 
 void KMountManGUI::gettingSpaceData( const QString &mountPoint, unsigned long kBSize,
-                                     unsigned long kBUsed, unsigned long kBAvail ) {
+                                     unsigned long /*kBUsed*/, unsigned long kBAvail ) {
    KMountPoint *m = KMountMan::findInListByMntPoint( mounted, mountPoint );
    if ( !m ) { // this should never never never happen!
       KMessageBox::error( 0, i18n( "Critical Error" ),
@@ -256,7 +259,7 @@ void KMountManGUI::updateList() {
 }
 
 void KMountManGUI::checkMountChange() {
-	if (QFileInfo(MTAB).lastModified() != lastMtab)
+	if (KrMountDetector::getInstance()->hasMountsChanged())
 		getSpaceData();
    watcher->start( WATCHER_DELAY, true );   // starting the watch timer ( single shot )
 }
@@ -300,7 +303,7 @@ void KMountManGUI::changeActive( QListViewItem *i ) {
 }
 
 // called when right-clicked on a filesystem
-void KMountManGUI::clicked( QListViewItem *item ) {
+void KMountManGUI::clicked( QListViewItem *item, const QPoint& pos, int col ) {
    // these are the values that will exist in the menu
 #define MOUNT_ID       90
 #define UNMOUNT_ID     91
@@ -342,7 +345,7 @@ void KMountManGUI::clicked( QListViewItem *item ) {
       popup.setItemEnabled( FORMAT_ID, false );
    }
 
-   int result = popup.exec( QCursor::pos() );
+   int result = popup.exec( pos );
    // check out the user's option
    switch ( result ) {
          case - 1 : return ;     // the user clicked outside of the menu
@@ -358,4 +361,33 @@ void KMountManGUI::clicked( QListViewItem *item ) {
    }
 }
 
+KrMountDetector::KrMountDetector() {
+   hasMountsChanged();
+}
+
+bool KrMountDetector::hasMountsChanged() {
+#if defined(BSD)
+   KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::NeedRealDeviceName);
+   KMD5 md5;
+   for(KMountPoint::List::iterator i = mountPoints.begin(); i != mountPoints.end(); ++i) {
+      md5.update((*i)->mountedFrom().utf8());
+      md5.update((*i)->realDeviceName().utf8());
+      md5.update((*i)->mountPoint().utf8());
+      md5.update((*i)->mountType().utf8());
+   }
+   QString s = md5.hexDigest();
+   bool result = s != checksum;
+   checksum = s;
+#else
+   bool result = QFileInfo(MTAB).lastModified() != lastMtab;
+   lastMtab = QFileInfo(MTAB).lastModified();
+#endif
+   return result;
+}
+
+KrMountDetector krMountDetector;
+KrMountDetector * KrMountDetector::getInstance() {
+   return & krMountDetector;
+}
+
 #include "kmountmangui.moc"
