@@ -40,8 +40,6 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../GUI/kcmdline.h"
 #include "../Dialogs/krspecialwidgets.h"
 #include "../panelmanager.h"
-#include "listpanel.h"
-#include "panelfunc.h"
 #include <qlayout.h>
 #include <qdir.h>
 #include <qwhatsthis.h>
@@ -53,6 +51,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
+#include <qdict.h>
 
 //////////////////////////////////////////////////////////////////////////
 //  The following is KrDetailedView's settings in KConfig:
@@ -81,18 +80,20 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #define CANCEL_TWO_CLICK_RENAME {singleClicked = false;renameTimer.stop();}
 #define COLUMN(X)	static_cast<KrDetailedViewProperties*>(_properties)->column[ KrDetailedViewProperties::X ]
 #define PROPS	static_cast<KrDetailedViewProperties*>(_properties)	
+#define VF	getVfile()
 
 #define COLUMN_POPUP_IDS    91
 
 QString KrDetailedView::ColumnName[ KrDetailedViewProperties::MAX_COLUMNS ];
 
-KrDetailedView::KrDetailedView( QWidget *parent, ListPanel *panel, bool &left, KConfig *cfg, const char *name ) :
-      KListView( parent, name ), KrView( cfg ), _focused( false ), _currDragItem( 0L ),
-      _nameInKConfig( QString( "KrDetailedView" ) + QString( ( left ? "Left" : "Right" ) ) ), _left( left ),
-      currentlyRenamedItem( 0 )    {
-	initProperties(); // don't forget this!
-        lastSwushPosition = 0;
+KrDetailedView::KrDetailedView( QWidget *parent, bool &left, KConfig *cfg, const char *name ) :
+      KListView( parent, name ), KrView( cfg ), _currDragItem( 0L ), currentlyRenamedItem( 0 ) {
+	setWidget( this );
+	_nameInKConfig=QString( "KrDetailedView" ) + QString( ( left ? "Left" : "Right" ) ) ;
+}
 
+void KrDetailedView::setup() {
+	lastSwushPosition = 0;
    if ( ColumnName[ 0 ].isEmpty() ) {
       ColumnName[ 0 ] = i18n( "Name" );
       ColumnName[ 1 ] = i18n( "Ext" );
@@ -121,6 +122,8 @@ KrDetailedView::KrDetailedView( QWidget *parent, ListPanel *panel, bool &left, K
       connect( this, SIGNAL( onItem( QListViewItem* ) ), this, SLOT( slotItemDescription( QListViewItem* ) ) );
       connect( this, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
                this, SLOT( handleContextMenu( QListViewItem*, const QPoint&, int ) ) );
+		connect( this, SIGNAL( rightButtonPressed(QListViewItem*, const QPoint&, int)),
+			this, SLOT(slotRightButtonPressed(QListViewItem*, const QPoint&, int)));
       connect( this, SIGNAL( currentChanged( QListViewItem* ) ), this, SLOT( setNameToMakeCurrent( QListViewItem* ) ) );
       connect( this, SIGNAL( mouseButtonClicked ( int, QListViewItem *, const QPoint &, int ) ),
                this, SLOT( slotMouseClicked ( int, QListViewItem *, const QPoint &, int ) ) );
@@ -128,10 +131,8 @@ KrDetailedView::KrDetailedView( QWidget *parent, ListPanel *panel, bool &left, K
 		connect( header(), SIGNAL(clicked(int)), this, SLOT(sortOrderChanged(int )));
    }
 
-   setWidget( this );
-
    // add whatever columns are needed to the listview
-   krConfig->setGroup( "Look&Feel" );
+   krConfig->setGroup( nameInKConfig() );
    
 	newColumn( KrDetailedViewProperties::Name );  // we always have a name
    setColumnWidthMode( COLUMN(Name), QListView::Manual );
@@ -201,20 +202,10 @@ KrDetailedView::KrDetailedView( QWidget *parent, ListPanel *panel, bool &left, K
    // allow in-place renaming
    connect( renameLineEdit(), SIGNAL( done( QListViewItem *, int ) ),
             this, SLOT( inplaceRenameFinished( QListViewItem*, int ) ) );
-   connect( this, SIGNAL( renameItem( const QString &, const QString & ) ),
-            panel->func, SLOT( rename( const QString &, const QString & ) ) );
-   // connect quicksearch
-   connect( panel->quickSearch, SIGNAL( textChanged( const QString& ) ),
-            this, SLOT( quickSearch( const QString& ) ) );
-   connect( panel->quickSearch, SIGNAL( otherMatching( const QString&, int ) ),
-            this, SLOT( quickSearch( const QString& , int ) ) );
-   connect( panel->quickSearch, SIGNAL( stop( QKeyEvent* ) ),
-            this, SLOT( stopQuickSearch( QKeyEvent* ) ) );
-   connect( panel->quickSearch, SIGNAL( process( QKeyEvent* ) ),
-            this, SLOT( handleQuickSearchEvent( QKeyEvent* ) ) );
    connect( &renameTimer, SIGNAL( timeout() ), this, SLOT( renameCurrentItem() ) );
    connect( &contextMenuTimer, SIGNAL (timeout()), this, SLOT (showContextMenu()));
 
+	connect( header(), SIGNAL(clicked(int)), this, SLOT(slotSortOrderChanged(int )));
 
    setFocusPolicy( StrongFocus );
    restoreSettings();
@@ -224,8 +215,8 @@ KrDetailedView::KrDetailedView( QWidget *parent, ListPanel *panel, bool &left, K
 }
 
 KrDetailedView::~KrDetailedView() {
-	delete _properties;
-	_properties = 0;
+	delete _properties; _properties = 0;
+	delete _operator; _operator = 0;
 }
 
 void KrDetailedView::newColumn( KrDetailedViewProperties::ColumnType type ) {
@@ -249,8 +240,9 @@ void KrDetailedView::newColumn( KrDetailedViewProperties::ColumnType type ) {
 int KrDetailedView::column( KrDetailedViewProperties::ColumnType type ) {
 	return PROPS->column[type];
 }
- 
-void KrDetailedView::addItem( vfile *vf ) {
+
+// if vfile passes the filter, create an item, otherwise, drop it
+KrViewItem *KrDetailedView::preAddItem( vfile *vf ) {
    QString size = KRpermHandler::parseSize( vf->vfile_getSize() );
    QString name = vf->vfile_getName();
    bool isDir = vf->vfile_isDir();
@@ -259,71 +251,22 @@ void KrDetailedView::addItem( vfile *vf ) {
             case KrViewProperties::All :
                break;
             case KrViewProperties::Custom :
-            if ( !_properties->filterMask.match( vf ) ) return ;
+            if ( !_properties->filterMask.match( vf ) ) return 0;
             break;
             case KrViewProperties::Dirs:
-            if ( !vf->vfile_isDir() ) return ;
+            if ( !vf->vfile_isDir() ) return 0;
             break;
             case KrViewProperties::Files:
-            if ( vf->vfile_isDir() ) return ;
+            if ( vf->vfile_isDir() ) return 0;
             break;
             case KrViewProperties::ApplyToDirs :
             break; // no-op, stop compiler complaints
       }
    }
    // passed the filter ...
-   KrDetailedViewItem *item = new KrDetailedViewItem( this, lastItem(), vf );
-   // add to dictionary
-   dict.insert( vf->vfile_getName(), item );
-   if ( isDir )
-      ++_numDirs;
-   else _countSize += static_cast<KrViewItem*>( item ) ->size();
-   ++_count;
-   
-   if (item->name() == nameToMakeCurrent() )
-      setCurrentItem(item->name()); // dictionary based - quick
-
-   ensureItemVisible( currentItem() );
-   emit selectionChanged();
+	return new KrDetailedViewItem( this, lastItem(), vf );
 }
 
-void KrDetailedView::delItem( const QString &name ) {
-	 KrDetailedViewItem * it = dict[ name ];
-   if ( !it ) {
-      krOut << "got signal deletedVfile(" << name << ") but can't find KrViewItem" << endl;
-		return;
-	} 
-	if (it->isDir()) {
-		--_numDirs;
-	} else {
-		_countSize -= it->size();
-	}
-	--_count;
-	
-	delete it;
-	emit selectionChanged();
-}
-
-void KrDetailedView::updateItem( vfile *vf ) {
-   // since we're deleting the item, make sure we keep
-   // it's properties first and repair it later
-   KrDetailedViewItem * it = dict[ vf->vfile_getName() ];
-   if ( !it ) {
-      krOut << "got signal updatedVfile(" << vf->vfile_getName() << ") but can't find KrViewItem" << endl;
-   } else {
-		bool selected = it->isSelected();
-      bool current = ( getCurrentKrViewItem() == it );
-      delItem( vf->vfile_getName() );
-      addItem( vf );
-      // restore settings
-      ( dict[ vf->vfile_getName() ] ) ->setSelected( selected );
-      if ( current )
-         setCurrentItem( vf->vfile_getName() );
-   }
-	emit selectionChanged();
-}
-
-
 void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
    QListViewItem * item = firstChild();
    QListViewItem *currentItem = item;
@@ -334,11 +277,6 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
       new KrDetailedViewItem( this, ( QListViewItem* ) 0L, ( vfile* ) 0L );
    }
 
-   // add a progress bar to the totals statusbar
-   //	KProgress *pr = new KProgress(krApp->mainView->activePanel->totals);
-   //  krApp->mainView->activePanel->totals->addWidget(pr,true);
-   //  pr->setTotalSteps(v->vfs_noOfFiles());
-   // make sure the listview stops sorting itself - it makes us slower!
    int cnt = 0;
    int cl = columnSorted();
    bool as = ascendingSort();
@@ -371,32 +309,24 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
       }
 
       KrDetailedViewItem *dvitem = new KrDetailedViewItem( this, item, vf );
-      dict.insert( vf->vfile_getName(), dvitem );
+      _dict.insert( vf->vfile_getName(), dvitem );
       if ( isDir )
          ++_numDirs;
       else
-         _countSize += dvitem->size();
+         _countSize += dvitem->VF->vfile_getSize();
       ++_count;
       // if the item should be current - make it so
       if ( dvitem->name() == nameToMakeCurrent() )
          currentItem = static_cast<QListViewItem*>(dvitem);
 
       cnt++;
-      //    if (cnt % 300 == 0) {
-      //      pr->show();
-      //      pr->advance(300);
-      //      kapp->processOneEvent();
-      //    }
    }
 
-   // kill progressbar
-   //  krApp->mainView->activePanel->totals->removeWidget(pr);
-   //  delete(pr);
 
    // re-enable sorting
    setSorting( cl, as );
    sort();
-
+	
    if ( !currentItem )
       currentItem = firstChild();
    KListView::setCurrentItem( currentItem );
@@ -412,25 +342,15 @@ QString KrDetailedView::getCurrentItem() const {
 }
 
 void KrDetailedView::setCurrentItem( const QString& name ) {
-   KrDetailedViewItem * it = dict[ name ];
+   KrDetailedViewItem * it = dynamic_cast<KrDetailedViewItem*>(_dict[ name ]);
    if ( it )
       KListView::setCurrentItem( it );
-#if 0
-   for ( QListViewItem * it = firstChild(); it != 0; it = it->itemBelow() )
-      if ( static_cast<KrViewItem*>( it ) ->
-            name() == name ) {
-         KListView::setCurrentItem( it );
-         break;
-      }
-#endif
-
 }
 
 void KrDetailedView::clear() {
-   emit KListView::selectionChanged(); /* to avoid rename crash at refresh */
+	op()->emitSelectionChanged(); /* to avoid rename crash at refresh */
    KListView::clear();
-   _count = _numSelected = _numDirs = _selectedSize = _countSize = 0;
-   dict.clear();
+   KrView::clear();
 }
 
 void KrDetailedView::setSortMode( KrViewProperties::SortSpec mode ) {
@@ -497,15 +417,17 @@ void KrDetailedView::slotDoubleClicked( QListViewItem *item ) {
    if ( !item )
       return ;
    QString tmp = dynamic_cast<KrViewItem*>( item ) ->name();
-   emit executed( tmp );
+   op()->emitExecuted(tmp);
 }
 
 void KrDetailedView::prepareForActive() {
+	KrView::prepareForActive();
    setFocus();
-   _focused = true;
+   slotItemDescription( currentItem() );
 }
 
 void KrDetailedView::prepareForPassive() {
+	KrView::prepareForPassive();
    CANCEL_TWO_CLICK_RENAME;
    if ( renameLineEdit() ->isVisible() )
       renameLineEdit() ->clearFocus();
@@ -521,7 +443,6 @@ void KrDetailedView::prepareForPassive() {
          }
       }
    }
-   _focused = false;
 }
 
 void KrDetailedView::slotItemDescription( QListViewItem * item ) {
@@ -529,7 +450,7 @@ void KrDetailedView::slotItemDescription( QListViewItem * item ) {
    if ( !it )
       return ;
    QString desc = it->description();
-   emit itemDescription( desc );
+   op()->emitItemDescription(desc);
 }
 
 void KrDetailedView::handleQuickSearchEvent( QKeyEvent * e ) {
@@ -642,7 +563,7 @@ void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
    }
 
    if ( !_focused )
-      emit needFocus();
+   	op()->emitNeedFocus();
    if (processEvent && ( (e->state() & ShiftButton) || (e->state() & ControlButton) || (e->state() & AltButton) ) && !KrSelectionMode::getSelectionHandler()->useQTSelection()){
       if ( oldCurrent && newCurrent && oldCurrent != newCurrent && e->state() & ShiftButton ) {
          int oldPos = oldCurrent->itemPos();
@@ -749,13 +670,13 @@ void KrDetailedView::contentsMouseMoveEvent ( QMouseEvent * e ) {
 
 void KrDetailedView::contentsWheelEvent( QWheelEvent * e ) {
    if ( !_focused )
-      emit needFocus();
+      op()->emitNeedFocus();
    KListView::contentsWheelEvent( e );
 }
 
 void KrDetailedView::handleContextMenu( QListViewItem * it, const QPoint & pos, int ) {
    if ( !_focused )
-      emit needFocus();
+      op()->emitNeedFocus();
    if ( !it )
       return ;
    if ( static_cast<KrDetailedViewItem*>( it ) ->
@@ -773,24 +694,11 @@ void KrDetailedView::showContextMenu()
 {
 	if (lastSwushPosition)
 		lastSwushPosition->setSelected(true);
-   emit contextMenu( contextMenuPoint );
-}
-
-void KrDetailedView::startDrag() {
-   QStringList items;
-   getSelectedItems( &items );
-   if ( items.empty() )
-      return ; // don't drag an empty thing
-   QPixmap px;
-   if ( items.count() > 1 )
-      px = FL_LOADICON( "queue" ); // how much are we dragging
-   else
-      px = getCurrentKrViewItem() ->icon();
-   emit letsDrag( items, px );
+	op()->emitContextMenu( contextMenuPoint );
 }
 
 KrViewItem *KrDetailedView::getKrViewItemAt( const QPoint & vp ) {
-   return static_cast<KrDetailedViewItem*>( KListView::itemAt( vp ) );
+   return dynamic_cast<KrViewItem*>( KListView::itemAt( vp ) );
 }
 
 bool KrDetailedView::acceptDrag( QDropEvent* ) const {
@@ -812,19 +720,20 @@ QRect KrDetailedView::drawItemHighlighter(QPainter *painter, QListViewItem *item
 
 void KrDetailedView::contentsDropEvent( QDropEvent * e ) {
    e->setPoint( contentsToViewport( e->pos() ) );
-   emit gotDrop( e );
+   op()->emitGotDrop(e);
    e->ignore();
    KListView::contentsDropEvent( e );
 }
 
 void KrDetailedView::contentsDragMoveEvent( QDragMoveEvent * e ) {
    _currDragItem = getKrViewItemAt(contentsToViewport(e->pos()));
-   if( _currDragItem && !_currDragItem->isDir() )
+   if( _currDragItem && !_currDragItem->VF->vfile_isDir() )
      _currDragItem = 0;
    
    KListView::contentsDragMoveEvent( e );
 }
 
+// TODO: for brief mode, move as much of this as possible to the viewOperator
 void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
    if ( !e || !firstChild() )
       return ; // subclass bug
@@ -834,10 +743,7 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
    }
    switch ( e->key() ) {
          case Key_Up :
-			if (e->state() == ControlButton) { // let the panel handle it - jump to origin bar
-				e->ignore();
-				break;
-			} else if (!KrSelectionMode::getSelectionHandler()->useQTSelection()) {
+			if (!KrSelectionMode::getSelectionHandler()->useQTSelection()) {
             QListViewItem * i = currentItem();
             if ( !i ) break;
             if ( e->state() == ShiftButton ) setSelected( i, !i->isSelected() );
@@ -847,7 +753,7 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
 					QListView::ensureItemVisible( i );
 				}
          } else KListView::keyPressEvent(e);
-         return;
+         break;
          case Key_Down :
          if ( e->state() == ControlButton ) { // let the panel handle it - jump to command line
             e->ignore();
@@ -859,7 +765,7 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
             i = i->itemBelow();
          if ( i ) {QListView::setCurrentItem( i ); QListView::ensureItemVisible( i ); }
          } else KListView::keyPressEvent(e);
-         return;
+         break;
          case Key_Next:  if (!KrSelectionMode::getSelectionHandler()->useQTSelection()){
             QListViewItem * i = currentItem(), *j;
             if ( !i ) break;
@@ -869,7 +775,7 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
                i = j;
             if ( i ) {QListView::setCurrentItem( i ); QListView::ensureItemVisible( i ); }
          } else KListView::keyPressEvent(e);
-         return;
+         break;
          case Key_Prior:  if (!KrSelectionMode::getSelectionHandler()->useQTSelection()){
             QListViewItem * i = currentItem(), *j;
             if ( !i ) break;
@@ -879,13 +785,13 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
                i = j;
             if ( i ) {QListView::setCurrentItem( i ); QListView::ensureItemVisible( i ); }
          } else KListView::keyPressEvent(e);
-         return;
+         break;
          case Key_Home:  if (!KrSelectionMode::getSelectionHandler()->useQTSelection()){
             if ( e->state() & ShiftButton )  /* Shift+Home */
             {
                clearSelection();
                KListView::keyPressEvent( e );
-               emit selectionChanged();
+               op()->emitSelectionChanged();
                triggerUpdate();
                break;
             } else {
@@ -893,13 +799,13 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
                if ( i ) {QListView::setCurrentItem( i ); QListView::ensureItemVisible( i ); }
             }
          } else KListView::keyPressEvent(e);
-         return;
+         break;
          case Key_End:  if (!KrSelectionMode::getSelectionHandler()->useQTSelection()){
             if ( e->state() & ShiftButton )  /* Shift+End */
             {
                clearSelection();
                KListView::keyPressEvent( e );
-               emit selectionChanged();
+               op()->emitSelectionChanged();
                triggerUpdate();
                break;
             } else {
@@ -912,7 +818,7 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
                break;
             }
          } else KListView::keyPressEvent(e);
-         return;
+         break;
          case Key_Enter :
          case Key_Return : {
             if ( e->state() & ControlButton )         // let the panel handle it
@@ -920,7 +826,7 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
             else {
                KrViewItem * i = getCurrentKrViewItem();
                QString tmp = i->name();
-               emit executed( tmp );
+               op()->emitExecuted(tmp);
             }
             break;
          }
@@ -943,9 +849,9 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
                SLOTS->dirUp(); // ask krusader to move up a directory
                return ;
             }
-            if ( i->isDir() ) {             // we create a return-pressed event,
+            if ( i->VF->vfile_isDir() ) {             // we create a return-pressed event,
                QString tmp = i->name();
-               emit executed( tmp );  // thereby emulating a chdir
+               op()->emitExecuted(tmp); // thereby emulating a chdir
             }
             return ; // safety
          }
@@ -971,15 +877,15 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
          break;
 #endif*/
          case Key_Delete :                   // kill file
-         SLOTS->deleteFiles(e->state() == ShiftButton);
+         SLOTS->deleteFiles( e->state() == ShiftButton || e->state() == ControlButton );
 				
-         return ;
+         break ;
          case Key_Insert : {
             if (KrSelectionMode::getSelectionHandler()->insertMovesDown())
                KListView::keyPressEvent( e );
             else
                KListView::keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Space, 0, 0 ) );
-            return ; 
+            break ; 
          }
          case Key_Space : {
             KrDetailedViewItem * viewItem = static_cast<KrDetailedViewItem *> ( getCurrentKrViewItem() );
@@ -988,9 +894,10 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
                   KListView::keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Insert, 0, 0 ) );
                else
                   KListView::keyPressEvent( e );
-               return ; 
+               break ; 
             }
-            if ( viewItem->isDir() && viewItem->size() <= 0 &&  KrSelectionMode::getSelectionHandler()->spaceCalculatesDiskSpace()) {
+            if ( viewItem->VF->vfile_isDir() && viewItem->VF->vfile_getSize() <= 0 && 
+					KrSelectionMode::getSelectionHandler()->spaceCalculatesDiskSpace()) {
                //
                // NOTE: this is buggy incase somewhere down in the folder we're calculating,
                // there's a folder we can't enter (permissions). in that case, the returned
@@ -1043,6 +950,11 @@ mark:       if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
 							// first, show the quicksearch if its hidden
 							if ( ACTIVE_PANEL->quickSearch->isHidden() ) {
 								ACTIVE_PANEL->quickSearch->show();
+								// hack: if the pressed key requires a scroll down, the selected
+								// item is "below" the quick search window, as the list view will
+								// realize its new size after the key processing. The following line
+								// will resize the list view immediately.
+								ACTIVE_PANEL->layout->activate();
 								// second, we need to disable the dirup action - hack!
 								krDirUp->setEnabled( false );
 							}
@@ -1087,6 +999,8 @@ void KrDetailedView::renameCurrentItem() {
    int c;
    QString newName, fileName;
 
+	// handle inplace renaming, if possible
+	
    KrDetailedViewItem *it = static_cast<KrDetailedViewItem*>(getCurrentKrViewItem());
    if ( it )
       fileName = it->name();
@@ -1107,15 +1021,10 @@ void KrDetailedView::renameCurrentItem() {
       rename( static_cast<QListViewItem*>( it ), c );
       // signal will be emited when renaming is done, and finalization
       // will occur in inplaceRenameFinished()
-   } else { // do this in case inplace renaming is disabled
-      // good old dialog box
-      bool ok = false;
-      newName = KInputDialog::getText( i18n( "Rename" ), i18n( "Rename " ) + fileName + i18n( " to:" ),
-                                       fileName, &ok, krApp );
-      // if the user canceled - quit
-      if ( !ok || newName == fileName )
-         return ;
-      emit renameItem( it->name(), newName );
+   } else {
+   	// do this in case inplace renaming is disabled
+   	// this actually does the good old dialog box rename
+   	KrView::renameCurrentItem();
    }
 }
 
@@ -1131,13 +1040,18 @@ void KrDetailedView::inplaceRenameFinished( QListViewItem * it, int ) {
    // check if the item was indeed renamed
    bool restoreView = false;
    if ( it->text( COLUMN( Name ) ) != static_cast<KrDetailedViewItem*>( it ) ->name() ) { // was renamed
-      emit renameItem( static_cast<KrDetailedViewItem*>( it ) ->name(), it->text( COLUMN( Name ) ) );
+      op()->emitRenameItem( static_cast<KrDetailedViewItem*>( it ) ->name(), it->text( COLUMN( Name ) ) );
    } else restoreView = true;
 
+   // restore the view always! if the file was indeed renamed, we'll get a signal from the vfs about
+   // it, and update the view when needed
+#if 0
    if ( COLUMN( Extention ) != -1 && restoreView ) { // nothing happened, restore the view (if needed)
+#endif
+      
       int i;
       QString ext, name = static_cast<KrDetailedViewItem*>( it ) ->name();
-      if ( !static_cast<KrDetailedViewItem*>( it ) ->isDir() )
+      if ( !static_cast<KrDetailedViewItem*>( it ) ->VF->vfile_isDir() && COLUMN( Extention ) != -1 )
          if ( ( i = name.findRev( '.' ) ) > 0 ) {
             ext = name.mid( i + 1 );
             name = name.mid( 0, i );
@@ -1145,12 +1059,16 @@ void KrDetailedView::inplaceRenameFinished( QListViewItem * it, int ) {
       it->setText( COLUMN( Name ), name );
       it->setText( COLUMN( Extention ), ext );
       repaintItem( it );
+#if 0
    }
+#endif
+
    setFocus();
    
    currentlyRenamedItem = 0;
 }
 
+// TODO: move the whole quicksearch mess out of here and into krview
 void KrDetailedView::quickSearch( const QString & str, int direction ) {
    KrViewItem * item = getCurrentKrViewItem();
    KConfigGroupSaver grpSvr( _config, "Look&Feel" );
@@ -1185,13 +1103,7 @@ void KrDetailedView::stopQuickSearch( QKeyEvent * e ) {
    }
 }
 
-//void KrDetailedView::focusOutEvent( QFocusEvent * e )
-//{
-//  if ( krApp->mainView->activePanel->quickSearch->isShown() )
-//    stopQuickSearch(0);
-//  KListView::focusOutEvent( e );
-//}
-
+// internal: converts signal from qlistview to krview
 void KrDetailedView::setNameToMakeCurrent( QListViewItem * it ) {
 	if (!it) return;
    KrView::setNameToMakeCurrent( static_cast<KrDetailedViewItem*>( it ) ->name() );
@@ -1265,22 +1177,29 @@ bool KrDetailedView::eventFilter( QObject * watched, QEvent * e )
 }
 
 void KrDetailedView::makeItemVisible( const KrViewItem *item ) {
-	qApp->processEvents();
-	ensureItemVisible( static_cast<const KrDetailedViewItem*>( item ) ); 
+//	qApp->processEvents();  // Please don't remove the comment. Causes crash if it is inserted!
+	ensureItemVisible( static_cast<const KrDetailedViewItem*>( item ) );
+}
+
+void KrDetailedView::initOperator() {
+	_operator = new KrViewOperator(this, this);
+	// klistview emits selection changed, so chain them to operator
+	connect(this, SIGNAL(selectionChanged()), _operator, SIGNAL(selectionChanged()));
 }
 
 void KrDetailedView::initProperties() {
 	_properties = new KrDetailedViewProperties;
+	KConfigGroupSaver grpSvr( _config, "Look&Feel" );	
+	for (int i=0; i<KrDetailedViewProperties::MAX_COLUMNS;++i)
+		PROPS->column[i]=-1;	
 	PROPS->displayIcons = _config->readBoolEntry( "With Icons", _WithIcons );
 	PROPS->sortMode = static_cast<KrViewProperties::SortSpec>( KrViewProperties::Name |
 		KrViewProperties::Descending | KrViewProperties::DirsFirst );
-	{
-	KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+	PROPS->numericPermissions = _config->readBoolEntry("Numeric permissions", _NumericPermissions);
 	if ( !_config->readBoolEntry( "Case Sensative Sort", _CaseSensativeSort ) )
       	PROPS->sortMode = static_cast<KrViewProperties::SortSpec>( _properties->sortMode |
 				 KrViewProperties::IgnoreCase );
 	PROPS->humanReadableSize = krConfig->readBoolEntry("Human Readable Size", _HumanReadableSize);
-	}
 	PROPS->localeAwareCompareIsCaseSensitive = QString( "a" ).localeAwareCompare( "B" ) > 0; // see KDE bug #40131
 }
 
@@ -1326,7 +1245,7 @@ void KrDetailedView::selectColumns()
   
   int result=popup.exec(QCursor::pos());
 
-  krConfig->setGroup( "Look&Feel" );
+  krConfig->setGroup( nameInKConfig() );
   
   switch( result - COLUMN_POPUP_IDS )
   {
@@ -1366,8 +1285,8 @@ void KrDetailedView::selectColumns()
   
   if( refresh )
   {
-    QTimer::singleShot( 0, MAIN_VIEW->leftMng, SLOT( slotRecreatePanels() ) );
-    QTimer::singleShot( 0, MAIN_VIEW->rightMng, SLOT( slotRecreatePanels() ) );
+	 PanelManager *p = ACTIVE_PANEL->view == this ? ACTIVE_MNG : OTHER_MNG;
+    QTimer::singleShot( 0, p, SLOT( slotRecreatePanels() ) );
   }
 }
 
@@ -1375,5 +1294,61 @@ void KrDetailedView::sortOrderChanged(int) {
 	ensureItemVisible(currentItem());
 }
 
+void KrDetailedView::updateView() {
+	triggerUpdate(); 
+	op()->emitSelectionChanged();
+}
+
+void KrDetailedView::updateItem(KrViewItem* item) {
+	dynamic_cast<KrDetailedViewItem*>(item)->repaintItem();
+}
+
+void KrDetailedView::slotRightButtonPressed(QListViewItem*, const QPoint& point, int) {
+	op()->emitEmptyContextMenu(point);
+}
+
+// hack: this needs to be done in a more cross-view way
+void KrDetailedView::slotSortOrderChanged(int col) {
+	// map the column to a sort specification
+	KrViewProperties::SortSpec sp;
+	int i;
+	for (i = 0; i < KrDetailedViewProperties::MAX_COLUMNS; ++i) {
+		if (PROPS->column[i] == col) break;
+	}
+	switch (i) {
+		case KrDetailedViewProperties::Name:
+			sp = KrViewProperties::Name; break;
+		case KrDetailedViewProperties::Extention:
+			sp = KrViewProperties::Ext; break;
+		case KrDetailedViewProperties::Mime:
+			sp = KrViewProperties::Type; break;
+		case KrDetailedViewProperties::Size:
+			sp = KrViewProperties::Size; break;
+		case KrDetailedViewProperties::DateTime:
+			sp = KrViewProperties::Modified; break;
+		case KrDetailedViewProperties::Permissions:
+			sp = KrViewProperties::Permissions; break;
+		case KrDetailedViewProperties::KrPermissions:
+			sp = KrViewProperties::KrPermissions; break;
+		case KrDetailedViewProperties::Owner:
+			sp = KrViewProperties::Owner; break;
+		case KrDetailedViewProperties::Group:
+			sp = KrViewProperties::Group; break;
+		default: qFatal("slotSortOrderChanged: unknown column");
+	}
+	if (sortMode() & KrViewProperties::DirsFirst) 
+		sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::DirsFirst);
+	if (sortMode() & KrViewProperties::IgnoreCase)
+		sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::IgnoreCase);
+	if (sortMode() & KrViewProperties::Descending)
+		sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::Descending);
+	// fix the ascending/decending stuff
+	if (sortMode() == sp) {
+		if (sp & KrViewProperties::Descending) 
+			sp = static_cast<KrViewProperties::SortSpec>(sp &~ KrViewProperties::Descending);
+		else sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::Descending);
+	}
+	PROPS->sortMode = sp;
+}
 
 #include "krdetailedview.moc"
