@@ -36,7 +36,6 @@ A
 #include <qwidget.h>
 #include <qtimer.h>
 #include <qdatetime.h>
-#include <qdict.h>
 #include "krview.h"
 #include "krviewitem.h"
 
@@ -48,7 +47,7 @@ public:
 	static const int MAX_COLUMNS = 9;
    int column[ MAX_COLUMNS ];	// column[ColumnType] contains the number of the requested column.
 										// This is used by column() and whenever item uses text() or setText()
-	bool humanReadableSize;		// display size as KB, MB or just as a long number
+	bool numericPermissions; // show full permission column as octal numbers
 
 	KrDetailedViewProperties() {
 		for ( int i = 0; i < MAX_COLUMNS; i++ ) column[i] = Unused;
@@ -61,6 +60,7 @@ public:
 class QDragMoveEvent;
 class KrRenameTimerObject;
 class ListPanel;
+class KrDetailedViewItem;
 
 /**
  * KrDetailedView implements everthing and anything regarding a detailed view in a filemananger.
@@ -74,44 +74,39 @@ class KrDetailedView : public KListView, public KrView {
    friend class KrDetailedViewItem;
 
 public:
-   KrDetailedView( QWidget *parent, ListPanel *panel, bool &left, KConfig *cfg = krConfig, const char *name = 0 );
+   KrDetailedView( QWidget *parent, bool &left, KConfig *cfg = krConfig, const char *name = 0 );
    virtual ~KrDetailedView();
    virtual int column( KrDetailedViewProperties::ColumnType type );
-   virtual KrViewItem *getFirst() { return dynamic_cast<KrViewItem*>( firstChild() ); }
-   virtual KrViewItem *getLast() { return dynamic_cast<KrViewItem*>( lastChild() ); }
-   virtual KrViewItem *getNext( KrViewItem *current ) { return dynamic_cast<KrViewItem*>( dynamic_cast<KListViewItem*>( current ) ->itemBelow() ); }
-   virtual KrViewItem *getPrev( KrViewItem *current ) { return dynamic_cast<KrViewItem*>( dynamic_cast<KListViewItem*>( current ) ->itemAbove() ); }
-   virtual KrViewItem *getCurrentKrViewItem() { return dynamic_cast<KrViewItem*>( currentItem() ); }
+   virtual inline KrViewItem *getFirst() { return dynamic_cast<KrViewItem*>( firstChild() ); }
+   virtual inline KrViewItem *getLast() { return dynamic_cast<KrViewItem*>( lastChild() ); }
+   virtual inline KrViewItem *getNext( KrViewItem *current ) { return dynamic_cast<KrViewItem*>( dynamic_cast<KListViewItem*>( current ) ->itemBelow() ); }
+   virtual inline KrViewItem *getPrev( KrViewItem *current ) { return dynamic_cast<KrViewItem*>( dynamic_cast<KListViewItem*>( current ) ->itemAbove() ); }
+   virtual inline KrViewItem *getCurrentKrViewItem() { return dynamic_cast<KrViewItem*>( currentItem() ); }
    virtual KrViewItem *getKrViewItemAt( const QPoint &vp );
-   virtual KrViewItem *findItemByName( const QString &name ) { return dynamic_cast<KrViewItem*>( findItem( name, 0 ) ); }
+   virtual inline KrViewItem *findItemByName( const QString &name ) { return dynamic_cast<KrViewItem*>( findItem( name, 0 ) ); }
    virtual void addItems( vfs *v, bool addUpDir = true );
-	virtual void addItem(vfile *vf);
-	virtual void delItem(const QString &name);
-	virtual void updateItem(vfile *vf);
  	virtual QString getCurrentItem() const;
    virtual void makeItemVisible( const KrViewItem *item );	
    virtual void setCurrentItem( const QString& name );
-   virtual void updateView() { triggerUpdate(); emit selectionChanged(); }
+   virtual void updateView();
+   virtual void updateItem(KrViewItem* item);
    virtual void clear();
    virtual void sort() { KListView::sort(); }
    virtual void setSortMode( KrViewProperties::SortSpec mode );
    virtual void prepareForActive();
    virtual void prepareForPassive();
-   virtual void saveSettings() { KListView::saveLayout( _config, nameInKConfig() ); }
-   virtual void restoreSettings() { KListView::restoreLayout( _config, nameInKConfig() ); }
-   virtual QString nameInKConfig() { return _nameInKConfig; }
+   virtual inline void saveSettings() { KListView::saveLayout( _config, nameInKConfig() ); }
+   virtual inline void restoreSettings() { KListView::restoreLayout( _config, nameInKConfig() ); }
 
 signals:
-   void executed( QString &name );
-   void itemDescription( QString &desc );
-   void needFocus();
-   void contextMenu( const QPoint &point );
-   void letsDrag( QStringList items, QPixmap icon );
-   void gotDrop( QDropEvent *e );
-   void renameItem( const QString &oldName, const QString &newName );
    void middleButtonClicked( QListViewItem *item );
 
 protected:
+	virtual void setup();
+	virtual void initProperties();
+	virtual void initOperator();
+	virtual KrViewItem *preAddItem(vfile *vf);
+	virtual inline bool preDelItem(KrViewItem *item) { return true; } // nothing special to do
    void newColumn( KrDetailedViewProperties::ColumnType type );
    void selectColumns();
    
@@ -124,10 +119,9 @@ protected:
    virtual void contentsDropEvent( QDropEvent *e );
    virtual void contentsDragMoveEvent( QDragMoveEvent *e );
    virtual QRect drawItemHighlighter(QPainter *painter, QListViewItem *item);
-   virtual void startDrag();
+   virtual void startDrag() { op()->startDrag(); }
    virtual bool event( QEvent *e );
    virtual bool eventFilter( QObject * watched, QEvent * e );
-	virtual void initProperties();
 
 protected slots:
    void rename( QListViewItem *item, int c );
@@ -139,33 +133,33 @@ protected slots:
    virtual void renameCurrentItem();
    virtual void showContextMenu( );
    void inplaceRenameFinished( QListViewItem *it, int col );
-   void quickSearch( const QString &, int = 0 );
-   void stopQuickSearch( QKeyEvent* );
-   void handleQuickSearchEvent( QKeyEvent* );
    void setNameToMakeCurrent( QListViewItem *it );
 	void sortOrderChanged(int);
-
+	void slotRightButtonPressed(QListViewItem*, const QPoint& point, int);
+	void slotSortOrderChanged(int col);
+	
    /**
     * used internally to produce the signal middleButtonClicked()
     */
    void slotMouseClicked( int button, QListViewItem * item, const QPoint & pos, int c );
    inline void slotExecuted( QListViewItem* i ) {
       QString tmp = dynamic_cast<KrViewItem*>( i ) ->name();
-      emit executed( tmp );
+      op()->emitExecuted( tmp );
    }
 
 public slots:
    void refreshColors();
+   void quickSearch( const QString &, int = 0 );
+   void stopQuickSearch( QKeyEvent* );
+   void handleQuickSearchEvent( QKeyEvent* );
 
 private:
    static QString ColumnName[ KrDetailedViewProperties::MAX_COLUMNS ];
-   bool _focused, swushSelects;
+   bool swushSelects;
    QPoint dragStartPos;
    QListViewItem *lastSwushPosition;
    bool caseSensitiveSort;
    KrViewItem *_currDragItem;
-   QString _nameInKConfig;
-   bool &_left;
    bool singleClicked;
    bool modifierPressed;
    QTime clickTime;
@@ -173,8 +167,6 @@ private:
    QTimer renameTimer;
    QTimer contextMenuTimer;
    QPoint contextMenuPoint;
-	QDict<KrDetailedViewItem> dict;
-        
    QListViewItem *currentlyRenamedItem;
 };
 
