@@ -31,6 +31,8 @@
 #define KRVIEW_H
 
 #include <qpixmap.h>
+#include <qvariant.h>
+#include <qdict.h>
 #include "../krusader.h"
 #include "../VFS/vfile.h"
 #include "../VFS/vfs.h"
@@ -38,6 +40,10 @@
 
 #include <kdebug.h>
 
+class KrView;
+class KrViewItem;
+typedef QValueList<KrViewItem*> KrViewItemList;
+
 // KrViewProperties
 // This class is an interface class between KrView and KrViewItem
 // In order for KrViewItem to be as independant as possible, KrView holds 
@@ -58,8 +64,50 @@ public:
 	FilterSpec filter;	// what items to show (all, custom, exec)
 	KRQuery filterMask;	// what items to show (*.cpp, *.h etc)
 	bool localeAwareCompareIsCaseSensitive; // mostly, it is not! depends on LC_COLLATE
+	bool humanReadableSize;		// display size as KB, MB or just as a long number
 };
 
+// operator can handle two ways of doing things:
+// 1. if the view is a widget (inherits krview and klistview for example)
+// 2. if the view HAS A widget (a krview-son has a member of klistview)
+// this is done by specifying the view and the widget in the constructor,
+// even if they are actually the same object (specify it twice in that case)
+class KrViewOperator: public QObject {
+	Q_OBJECT
+public:
+	KrViewOperator(KrView *view, QWidget *widget);
+	~KrViewOperator();
+	KrView *view() const { return _view; }
+	QWidget *widget() const { return _widget; }
+	void startDrag();
+	
+	void emitSelectionChanged() { emit selectionChanged(); }
+	void emitGotDrop(QDropEvent *e) { emit gotDrop(e); }
+	void emitLetsDrag(QStringList items, QPixmap icon ) { emit letsDrag(items, icon); }
+	void emitItemDescription(QString &desc) { emit itemDescription(desc); }
+	void emitContextMenu(const QPoint &point) { emit contextMenu(point); }
+	void emitEmptyContextMenu(const QPoint &point) { emit emptyContextMenu(point); }
+   void emitRenameItem(const QString &oldName, const QString &newName) { emit renameItem(oldName, newName); }
+   void emitExecuted( QString &name ) { emit executed(name); }
+   void emitNeedFocus() { emit needFocus(); }
+	
+signals:
+	void selectionChanged();
+	void gotDrop( QDropEvent *e );
+	void letsDrag( QStringList items, QPixmap icon );
+	void itemDescription( QString &desc );
+   void contextMenu( const QPoint &point );
+   void emptyContextMenu( const QPoint& point );
+   void renameItem( const QString &oldName, const QString &newName );
+   void executed( QString &name );
+   void needFocus();
+
+	
+protected:
+	// never delete those
+	KrView *_view;
+	QWidget *_widget;
+};
 
 /****************************************************************************
  * READ THIS FIRST: Using the view
@@ -81,52 +129,60 @@ public:
  * 5) nameToMakeCurrent(), setNameToMakeCurrent() - work with QString
  *
  * IMPORTANT NOTE: every one who subclasses this must call initProperties() in the constructor !!!
- */
-class KrViewItem;
- 
-typedef QValueList<KrViewItem*> KrViewItemList;
+ */ 
 class KrView {
+friend class KrViewItem;
 public:
+  // instantiating a new view
+  // 1. new KrView
+  // 2. view->init()
+  // notes: constructor does as little as possible, setup() does the rest. esp, note that
+  // if you need something from operator or properties, move it into setup()
+  virtual void init();
+
+protected:
+  virtual void initProperties() { qFatal("Please implement your own initProperties() method"); }
+  virtual void initOperator() { qFatal("Please implement your own initOperator() method"); }
+  virtual void setup() { qFatal("Please implement your own setup() method"); }
+  
   ///////////////////////////////////////////////////////
   // Every view must implement the following functions //
   ///////////////////////////////////////////////////////
+public:
   virtual KrViewItem *getFirst() = 0;
+  virtual KrViewItem *getLast() = 0;
   virtual KrViewItem *getNext(KrViewItem *current) = 0;
   virtual KrViewItem *getPrev(KrViewItem *current) = 0;
   virtual KrViewItem *getCurrentKrViewItem() = 0;
   virtual KrViewItem *getKrViewItemAt(const QPoint &vp) = 0;
   virtual KrViewItem *findItemByName(const QString &name) = 0;
   virtual void addItems(vfs* v, bool addUpDir = true) = 0; // kill me, kill me now
-  virtual void addItem(vfile *vf) = 0;
-  virtual void delItem(const QString &name) = 0;
-  virtual void updateItem(vfile *vf) = 0;
   virtual QString getCurrentItem() const = 0;
   virtual void setCurrentItem(const QString& name) = 0;
   virtual void makeItemVisible(const KrViewItem *item) = 0;
-  virtual void clear() = 0;
+  virtual void clear();
   virtual void updateView() = 0;
+  virtual void updateItem(KrViewItem* item) = 0;
   virtual void sort() = 0;
   virtual void saveSettings() = 0;
   virtual void restoreSettings() = 0;
-  virtual void prepareForActive() = 0;
-  virtual void prepareForPassive() = 0;
-  virtual QString nameInKConfig() = 0;
-  virtual void renameCurrentItem() = 0; // Rename current item. returns immediatly
-protected:
-  virtual void initProperties() = 0;
-  
-public:  
-  // also, the following must be implemented (but must be remarked here)
-  //
-  // signals:
-  //   void letsDrag(QStringList items, QPixmap icon);
-  //   void gotDrop(QDropEvent *);
-  //   void selectionChanged();
+  virtual void prepareForActive() { _focused = true; }
+  virtual void prepareForPassive() { _focused = false; }
+  virtual void renameCurrentItem(); // Rename current item. returns immediatly
+  virtual QString nameInKConfig() const { return _nameInKConfig; }
 
+protected:
+	virtual KrViewItem *preAddItem(vfile *vf) = 0;
+	virtual bool preDelItem(KrViewItem *item) = 0;
+
+public:
   //////////////////////////////////////////////////////
   // the following functions are already implemented, //
   // and normally - should NOT be re-implemented.     //
   //////////////////////////////////////////////////////
+  virtual KrViewItem *addItem(vfile *vf);
+  virtual void updateItem(vfile *vf);
+  virtual void delItem(const QString &name);
   virtual uint numSelected() const { return _numSelected; }
   virtual KIO::filesize_t selectedSize() const { return _selectedSize; }
   virtual uint numFiles() const { return _count-_numDirs; }
@@ -142,9 +198,12 @@ public:
   virtual void invertSelection();
   virtual QString nameToMakeCurrent() const { return _nameToMakeCurrent; }
   virtual void setNameToMakeCurrent(const QString name) { _nameToMakeCurrent = name; }
+  virtual QString nameToMakeCurrentIfAdded() const { return _nameToMakeCurrentIfAdded; }
+  virtual void setNameToMakeCurrentIfAdded(const QString name) { _nameToMakeCurrentIfAdded = name; }  
   virtual QString firstUnmarkedBelowCurrent();
   virtual QString statistics();
-  const KrViewProperties* properties() const { return _properties; }
+  virtual const KrViewProperties* properties() const { return _properties; }
+  virtual KrViewOperator* op() const { return _operator; }
 
   /////////////////////////////////////////////////////////////
   // the following functions have a default and minimalistic //
@@ -155,7 +214,7 @@ public:
   virtual void setFilter(KrViewProperties::FilterSpec filter) { _properties->filter = filter; }
   virtual KrViewProperties::FilterSpec filter() const { return _properties->filter; }
   virtual void setFilterMask( KRQuery mask ) { _properties->filterMask = mask; }
-  virtual KRQuery filterMask() const { return _properties->filterMask; }
+  virtual const KRQuery& filterMask() const { return _properties->filterMask; }
   inline QWidget *widget() { return _widget; }
   inline void setWidget(QWidget *w) { _widget = w; }
 
@@ -171,10 +230,15 @@ protected:
   KConfig *_config;
   QWidget *_widget;
   QString _nameToMakeCurrent;
+  QString _nameToMakeCurrentIfAdded;
   uint _numSelected, _count, _numDirs;
   KIO::filesize_t _countSize, _selectedSize;
   bool _left;
   KrViewProperties *_properties;
+  KrViewOperator *_operator;
+  QDict<KrViewItem> _dict;
+  bool _focused;
+  QString _nameInKConfig;
 };
 
 #endif /* KRVIEW_H */
