@@ -36,7 +36,6 @@
 #include "../Panel/listpanel.h"
 #include "../Panel/panelfunc.h"
 #include "../Dialogs/krdialogs.h"
-#include "../VFS/krpermhandler.h"
 #include "../VFS/virt_vfs.h"
 #include "../KViewer/krviewer.h"
 #include "krsearchmod.h"
@@ -54,6 +53,8 @@
 #include <qclipboard.h>
 #include <qheader.h>
 
+KrSearchDialog *KrSearchDialog::SearchDialog = 0;
+
 QString KrSearchDialog::lastSearchText = "*";
 int KrSearchDialog::lastSearchType = 0;
 bool KrSearchDialog::lastSearchForCase = false;
@@ -65,23 +66,23 @@ bool KrSearchDialog::lastFollowSymLinks = false;
 
 // class starts here /////////////////////////////////////////
 KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* name, bool modal, WFlags fl )
-                : QDialog( parent, name, modal, fl ), query(0), searcher(0) 
+                : QDialog( parent, name, modal, fl ), query(0), searcher(0)
 {
   setCaption( i18n( "Krusader::Search" ) );
-  
+
   QGridLayout* searchBaseLayout = new QGridLayout( this );
   searchBaseLayout->setSpacing( 6 );
   searchBaseLayout->setMargin( 11 );
 
   // creating the dialog buttons ( Search, Stop, Close )
-  
+
   QHBoxLayout* buttonsLayout = new QHBoxLayout();
   buttonsLayout->setSpacing( 6 );
   buttonsLayout->setMargin( 0 );
 
   profileManager = new ProfileManager( "SearcherProfile", this, "profileManager" );
   buttonsLayout->addWidget( profileManager );
-  
+
   QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
   buttonsLayout->addItem( spacer );
 
@@ -89,7 +90,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   mainFeedToListBoxBtn->setText( i18n( "Feed to listbox" ) );
   mainFeedToListBoxBtn->setEnabled(false);
   buttonsLayout->addWidget( mainFeedToListBoxBtn );
-  
+
   mainSearchBtn = new QPushButton( this, "mainSearchBtn" );
   mainSearchBtn->setText( i18n( "Search" ) );
   mainSearchBtn->setDefault(true);
@@ -107,15 +108,11 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   searchBaseLayout->addLayout( buttonsLayout, 1, 0 );
 
   // creating the searcher tabs
-  
+
   searcherTabs = new QTabWidget( this, "searcherTabs" );
 
-  generalFilter = new GeneralFilter( HAS_DONT_SEARCH_IN | HAS_SEARCH_IN | HAS_RECURSE_OPTIONS, 
-                                     searcherTabs, "generalFilter" );
-  searcherTabs->insertTab( generalFilter, i18n( "&General" ) );
-
-  advancedFilter = new AdvancedFilter( searcherTabs, "advancedFilter" );
-  searcherTabs->insertTab( advancedFilter, i18n( "&Advanced" ) );
+  filterTabs = FilterTabs::addTo( searcherTabs, FilterTabs::Default );
+  generalFilter = (GeneralFilter *)filterTabs->get( "GeneralFilter" );
 
   resultTab = new QWidget( searcherTabs, "resultTab" );
   resultLayout = new QGridLayout( resultTab );
@@ -123,7 +120,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   resultLayout->setMargin( 11 );
 
   // creating the result tab
-    
+
   QHBoxLayout* resultLabelLayout = new QHBoxLayout();
   resultLabelLayout->setSpacing( 6 );
   resultLabelLayout->setMargin( 0 );
@@ -141,7 +138,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   searchingLabel->setText( "" );
   resultLabelLayout->addWidget( searchingLabel );
 
-  resultLayout->addLayout( resultLabelLayout, 1, 0 );
+  resultLayout->addLayout( resultLabelLayout, 2, 0 );
 
   // creating the result list view
 
@@ -153,7 +150,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   resultsList->addColumn( i18n( "Permissions" ) );
 
   resultsList->setSorting(1); // sort by location
-  
+
   // fix the results list
   // => make the results font smaller
   QFont resultsFont(  resultsList->font() );
@@ -163,42 +160,65 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   resultsList->setAllColumnsShowFocus(true);
   for (int i=0; i<5; ++i) // don't let it resize automatically
     resultsList->setColumnWidthMode(i, QListView::Manual);
-    
+
   int i=QFontMetrics(resultsList->font()).width("W");
   int j=QFontMetrics(resultsList->font()).width("0");
   j=(i>j ? i : j);
-  
+
   resultsList->setColumnWidth(0, krConfig->readNumEntry("Name Width", j*14) );
   resultsList->setColumnWidth(1, krConfig->readNumEntry("Path Width", j*25) );
   resultsList->setColumnWidth(2, krConfig->readNumEntry("Size Width", j*6) );
   resultsList->setColumnWidth(3, krConfig->readNumEntry("Date Width", j*7) );
   resultsList->setColumnWidth(4, krConfig->readNumEntry("Perm Width", j*7) );
   resultsList->setColumnAlignment( 2, AlignRight );
-  
+
   resultsList->header()->setStretchEnabled( true, 1 );
-  
+
   resultLayout->addWidget( resultsList, 0, 0 );
+
+  QHBoxLayout* foundTextLayout = new QHBoxLayout();
+  foundTextLayout->setSpacing( 6 );
+  foundTextLayout->setMargin( 0 );
+  
+  QLabel *l1 = new QLabel(resultTab);
+  l1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, l1->sizePolicy().hasHeightForWidth() ) );
+  l1->setFrameShape( QLabel::StyledPanel );
+  l1->setFrameShadow( QLabel::Sunken );
+  l1->setText(i18n("Text found:"));
+  foundTextLayout->addWidget( l1 );
+
+  foundTextLabel = new KrSqueezedTextLabel(resultTab);
+  foundTextLabel->setFrameShape( QLabel::StyledPanel );
+  foundTextLabel->setFrameShadow( QLabel::Sunken );
+  foundTextLabel->setText("");
+  foundTextLayout->addWidget( foundTextLabel );
+  resultLayout->addLayout(foundTextLayout, 1, 0);
+  
   searcherTabs->insertTab( resultTab, i18n( "&Results" ) );
 
   searchBaseLayout->addWidget( searcherTabs, 0, 0 );
 
   // signals and slots connections
-  
+
   connect( mainSearchBtn, SIGNAL( clicked() ), this, SLOT( startSearch() ) );
   connect( mainStopBtn, SIGNAL( clicked() ), this, SLOT( stopSearch() ) );
-  connect( resultsList, SIGNAL( returnPressed(QListViewItem*) ), this, SLOT( resultClicked(QListViewItem*) ) );
-  connect( resultsList, SIGNAL( doubleClicked(QListViewItem*) ), this, SLOT( resultClicked(QListViewItem*) ) );
+  connect( resultsList, SIGNAL( returnPressed(QListViewItem*) ), this,
+  	SLOT( resultDoubleClicked(QListViewItem*) ) );
+  connect( resultsList, SIGNAL( doubleClicked(QListViewItem*) ), this,
+  	SLOT( resultDoubleClicked(QListViewItem*) ) );
+  connect( resultsList, SIGNAL( currentChanged(QListViewItem*) ), this,
+  		SLOT( resultClicked(QListViewItem*) ) );
+  connect( resultsList, SIGNAL( clicked(QListViewItem*) ), this,
+  		SLOT( resultClicked(QListViewItem*) ) );
   connect( resultsList, SIGNAL( rightButtonClicked(QListViewItem*,const QPoint&,int) ), this, SLOT( rightClickMenu(QListViewItem*, const QPoint&, int) ) );
   connect( mainCloseBtn, SIGNAL( clicked() ), this, SLOT( closeDialog() ) );
   connect( mainFeedToListBoxBtn, SIGNAL( clicked() ), this, SLOT( feedToListBox() ) );
-  
-  connect( profileManager, SIGNAL( loadFromProfile( QString ) ), generalFilter, SLOT( loadFromProfile( QString ) ) );
-  connect( profileManager, SIGNAL( saveToProfile( QString ) ), generalFilter, SLOT( saveToProfile( QString ) ) );
-  connect( profileManager, SIGNAL( loadFromProfile( QString ) ), advancedFilter, SLOT( loadFromProfile( QString ) ) );
-  connect( profileManager, SIGNAL( saveToProfile( QString ) ), advancedFilter, SLOT( saveToProfile( QString ) ) );
+
+  connect( profileManager, SIGNAL( loadFromProfile( QString ) ), filterTabs, SLOT( loadFromProfile( QString ) ) );
+  connect( profileManager, SIGNAL( saveToProfile( QString ) ), filterTabs, SLOT( saveToProfile( QString ) ) );
 
   // tab order
-  
+
   setTabOrder( mainSearchBtn, mainCloseBtn );
   setTabOrder( mainCloseBtn, mainStopBtn );
   setTabOrder( mainStopBtn, searcherTabs );
@@ -207,23 +227,21 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   krConfig->setGroup( "Search" );
   int sx = krConfig->readNumEntry( "Window Width",  -1 );
   int sy = krConfig->readNumEntry( "Window Height",  -1 );
-  
+
   if( sx != -1 && sy != -1 )
     resize( sx, sy );
-  
+
   if( krConfig->readBoolEntry( "Window Maximized",  false ) )
       showMaximized();
-  else  
+  else
       show();
-  
-  // disable the search action ... no 2 searchers !
-  krFind->setEnabled(false);
+
   generalFilter->searchFor->setFocus();
 
   isSearching = closed = false;
-  
+
   // finaly, load a profile of apply defaults:
-  
+
   if ( profile.isEmpty() ) {
     // load the last used values
     generalFilter->searchFor->setEditText( lastSearchText );
@@ -236,35 +254,35 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
     generalFilter->searchInArchives->setChecked( lastSearchInArchives );
     generalFilter->followLinks->setChecked( lastFollowSymLinks );
     // the path in the active panel should be the default search location
-    generalFilter->searchIn->lineEdit()->setText( ACTIVE_PANEL->virtualPath().prettyURL() ); 
+    generalFilter->searchIn->lineEdit()->setText( ACTIVE_PANEL->virtualPath().prettyURL() );
   }
   else
-    profileManager->loadByName( profile ); // important: call this _after_ you've connected profileManager ot the loadFromProfile!!
+    profileManager->loadProfile( profile ); // important: call this _after_ you've connected profileManager ot the loadFromProfile!!
 
 }
 
-void KrSearchDialog::closeDialog( bool isAccept ) 
+void KrSearchDialog::closeDialog( bool isAccept )
 {
   // stop the search if it's on-going
   if (searcher!=0) {
     delete searcher;
     searcher = 0;
   }
-  
+
   // saving the searcher state
-  
+
   krConfig->setGroup( "Search" );
-  
+
   krConfig->writeEntry("Window Width", sizeX );
   krConfig->writeEntry("Window Height", sizeY );
   krConfig->writeEntry("Window Maximized", isMaximized() );
-  
+
   krConfig->writeEntry("Name Width",  resultsList->columnWidth( 0 ) );
   krConfig->writeEntry("Path Width",  resultsList->columnWidth( 1 ) );
   krConfig->writeEntry("Size Width",  resultsList->columnWidth( 2 ) );
   krConfig->writeEntry("Date Width",  resultsList->columnWidth( 3 ) );
   krConfig->writeEntry("Perm Width",  resultsList->columnWidth( 4 ) );
-  
+
   lastSearchText = generalFilter->searchFor->currentText();
   lastSearchType = generalFilter->ofType->currentItem();
   lastSearchForCase = generalFilter->searchForCase->isChecked();
@@ -273,14 +291,14 @@ void KrSearchDialog::closeDialog( bool isAccept )
   lastSearchInSubDirs = generalFilter->searchInDirs->isChecked();
   lastSearchInArchives = generalFilter->searchInArchives->isChecked();
   lastFollowSymLinks = generalFilter->followLinks->isChecked();
-  hide();  
-  // re-enable the search action
-  krFind->setEnabled(true);
+  hide();
+  
+  SearchDialog = 0;
   if( isAccept )
     QDialog::accept();
   else
     QDialog::reject();
-  
+
   this->deleteLater();
 }
 
@@ -289,7 +307,7 @@ void KrSearchDialog::reject() {
 }
 
 void KrSearchDialog::resizeEvent( QResizeEvent *e )
-{   
+{
   if( !isMaximized() )
   {
     sizeX = e->size().width();
@@ -297,14 +315,16 @@ void KrSearchDialog::resizeEvent( QResizeEvent *e )
   }
 }
 
-void KrSearchDialog::found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm){
+void KrSearchDialog::found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm, QString foundText){
   // convert the time_t to struct tm
   struct tm* t=localtime((time_t *)&mtime);
   QDateTime tmp(QDate(t->tm_year+1900, t->tm_mon+1, t->tm_mday), QTime(t->tm_hour, t->tm_min));
-  new QListViewItem(resultsList, what, where.replace(QRegExp("\\\\"),"#"),
-                    KRpermHandler::parseSize(size), KGlobal::locale()->formatDateTime(tmp), perm);
+  ResultListViewItem *it =new ResultListViewItem(resultsList, what,
+  	 where.replace(QRegExp("\\\\"),"#"), size, KGlobal::locale()->formatDateTime(tmp), perm);
   QString totals = QString(i18n("Found %1 matches.")).arg(resultsList->childCount());
   foundLabel->setText(totals);
+
+  if (!foundText.isEmpty()) it->setFoundText(foundText);
 }
 
 bool KrSearchDialog::gui2query() {
@@ -313,44 +333,32 @@ bool KrSearchDialog::gui2query() {
   if (query!=0) { delete query; query = 0; }
   query = new KRQuery();
 
-  if( !generalFilter->fillQuery( query ) )
-  {
-    searcherTabs->setCurrentPage(0); // set page to general
-    return false;
-  }
-  
-  if( !advancedFilter->fillQuery( query ) )
-  {
-    searcherTabs->setCurrentPage(1); // set page to general
-    return false;
-  }
-  
-  return true;
+  return filterTabs->fillQuery( query );
 }
 
 void KrSearchDialog::startSearch() {
+
+  // prepare the query /////////////////////////////////////////////
+  if (!gui2query()) return;
+
   // first, informative messages
-  if (generalFilter->searchInArchives->isChecked()) {
+  if ( query->searchInArchives() ) {
     KMessageBox::information(this, i18n("Since you chose to also search in archives, "
                                         "note the following limitations:\n"
                                         "You cannot search for text (grep) while doing"
                                         " a search that includes archives."), 0, "searchInArchives");
   }
 
-  // prepare the query /////////////////////////////////////////////
-  if (!gui2query()) return;
-  // else implied
-  generalFilter->queryAccepted();
-
   // prepare the gui ///////////////////////////////////////////////
   mainSearchBtn->setEnabled(false);
   mainCloseBtn->setEnabled(false);
   mainStopBtn->setEnabled(true);
   mainFeedToListBoxBtn->setEnabled(false);
-  resultsList->clear(); 
+  resultsList->clear();
   searchingLabel->setText("");
   foundLabel->setText(i18n("Found 0 matches."));
   searcherTabs->setCurrentPage(2); // show the results page
+  foundTextLabel->setText("");
   qApp->processEvents();
 
   // start the search.
@@ -361,8 +369,8 @@ void KrSearchDialog::startSearch() {
   searcher  = new KRSearchMod(query);
   connect(searcher, SIGNAL(searching(const QString&)),
           searchingLabel, SLOT(setText(const QString&)));
-  connect(searcher, SIGNAL(found(QString,QString,KIO::filesize_t,time_t,QString)),
-                this, SLOT(found(QString,QString,KIO::filesize_t,time_t,QString)));
+  connect(searcher, SIGNAL(found(QString,QString,KIO::filesize_t,time_t,QString,QString)),
+                this, SLOT(found(QString,QString,KIO::filesize_t,time_t,QString,QString)));
   connect(searcher, SIGNAL(finished()), this, SLOT(stopSearch()));
 
   isSearching = true;
@@ -389,11 +397,24 @@ void KrSearchDialog::stopSearch() {
   searchingLabel->setText(i18n("Finished searching."));
 }
 
-void KrSearchDialog::resultClicked(QListViewItem* i) {
+void KrSearchDialog::resultDoubleClicked(QListViewItem* i) {
   ACTIVE_FUNC->openUrl(vfs::fromPathOrURL(i->text(1)),i->text(0));
   showMinimized();
 }
 
+void KrSearchDialog::resultClicked(QListViewItem* i) {
+	ResultListViewItem *it = dynamic_cast<ResultListViewItem*>(i);
+	if( it == 0 )
+		return;                
+	if (!it->foundText().isEmpty()) {
+		// ugly hack: find the <b> and </b> in the text, then
+		// use it to set the are which we don't want squeezed
+		int idx = it->foundText().find("<b>")-4; // take "<qt>" into account
+		int length = it->foundText().find("</b>")-idx+4;
+		foundTextLabel->setText(it->foundText(), idx, length);
+	}
+}
+
 void KrSearchDialog::closeEvent(QCloseEvent *e)
 {                     /* if searching is in progress we must not close the window */
   if( isSearching )   /* because qApp->processEvents() is called by the searcher and */
@@ -442,7 +463,7 @@ void KrSearchDialog::editCurrent()
     QString name = current->text(1);
     name += (name.endsWith( "/" ) ? current->text(0) : "/" + current->text(0) );
     KURL url = vfs::fromPathOrURL( name );
-    KrViewer::edit( url, true );
+    KrViewer::edit( url );
   }
 }
 
@@ -494,15 +515,15 @@ void KrSearchDialog::feedToListBox()
 {
   virt_vfs v(0,true);
   v.vfs_refresh( KURL( "/" ) );
-  
-  krConfig->setGroup( "Search" );  
-  int listBoxNum = krConfig->readNumEntry( "Feed To Listbox Counter", 1 );  
+
+  krConfig->setGroup( "Search" );
+  int listBoxNum = krConfig->readNumEntry( "Feed To Listbox Counter", 1 );
   QString queryName;
   do {
     queryName = i18n("Search results")+QString( " %1" ).arg( listBoxNum++ );
   }while( v.vfs_search( queryName ) != 0 );
-  krConfig->writeEntry( "Feed To Listbox Counter", listBoxNum );  
-  
+  krConfig->writeEntry( "Feed To Listbox Counter", listBoxNum );
+
   krConfig->setGroup( "Advanced" );
   if ( krConfig->readBoolEntry( "Confirm Feed to Listbox",  _ConfirmFeedToListbox ) ) {
     bool ok;
@@ -514,7 +535,7 @@ void KrSearchDialog::feedToListBox()
      if ( ! ok)
        return;
   }
-  
+
   KURL::List urlList;
   QListViewItem * item = resultsList->firstChild();
   while( item )
@@ -527,7 +548,7 @@ void KrSearchDialog::feedToListBox()
   KURL url = KURL::fromPathOrURL( QString("virt:/") + queryName );
   v.vfs_refresh( url );
   v.vfs_addFiles( &urlList, KIO::CopyJob::Copy, 0 );
-  //ACTIVE_FUNC->openUrl(url);  
+  //ACTIVE_FUNC->openUrl(url);
   ACTIVE_MNG->slotNewTab(url.prettyURL());
   closeDialog();
 }
