@@ -33,9 +33,10 @@
 #ifndef KRSEARCHDIALOG_H
 #define KRSEARCHDIALOG_H
 
-#include "../Dialogs/generalfilter.h"
-#include "../Dialogs/advancedfilter.h"
+#include "../Filter/filtertabs.h"
+#include "../Filter/generalfilter.h"
 #include "../VFS/krquery.h"
+#include "../VFS/krpermhandler.h"
 #include "krsearchmod.h"
 #include "../GUI/profilemanager.h"
 
@@ -60,8 +61,9 @@ public slots:
   void startSearch();
   void stopSearch();
   void feedToListBox();
-  void found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm);
+  void found(QString what, QString where, KIO::filesize_t size, time_t mtime, QString perm, QString foundText);
   void closeDialog( bool isAccept = true );
+  void resultDoubleClicked(QListViewItem*);
   void resultClicked(QListViewItem*);
 
   virtual void keyPressEvent(QKeyEvent *e);
@@ -69,6 +71,8 @@ public slots:
   virtual void rightClickMenu(QListViewItem*, const QPoint&, int);
   virtual void resizeEvent( QResizeEvent *e );
 
+  static KrSearchDialog *SearchDialog;
+  
 protected slots:
   void reject();
 
@@ -78,10 +82,11 @@ private:
   void viewCurrent();
 
 private:
-  GeneralFilter  *generalFilter;
-  AdvancedFilter *advancedFilter;
   ProfileManager *profileManager;
-    
+
+  FilterTabs * filterTabs;
+  GeneralFilter * generalFilter;
+      
   QPushButton* mainHelpBtn;
   QPushButton* mainSearchBtn;
   QPushButton* mainStopBtn;
@@ -92,7 +97,8 @@ private:
   QWidget* resultTab;
   QGridLayout* resultLayout;
   QLabel* foundLabel;
-  KSqueezedTextLabel* searchingLabel;
+  KrSqueezedTextLabel *foundTextLabel;
+  KSqueezedTextLabel *searchingLabel;
   
   QListView* resultsList;
 
@@ -115,4 +121,41 @@ private:
   int            sizeY;
 };
 
+class ResultListViewItem : public QListViewItem
+{
+public:
+  ResultListViewItem( QListView *resultsList, QString name, QString where, KIO::filesize_t size, 
+                      QString date, QString perm ) : QListViewItem( resultsList, name, where, 
+                      KRpermHandler::parseSize(size), date, perm )
+  {
+    fileSize = size;
+  }  
+
+  void setFoundText(QString text) { _foundText=text; }
+  const QString& foundText() const { return _foundText; }
+  
+  virtual int compare(QListViewItem *i,int col,bool ascending ) const
+  {
+    if( col == 2 ) {
+      ResultListViewItem *other = (ResultListViewItem *)i;
+      KIO::filesize_t otherSize = other->getSize();
+      
+      if( fileSize == otherSize )
+        return 0;
+      if( fileSize > otherSize )
+        return 1;
+      return -1;
+    }
+    return QListViewItem::compare( i, col, ascending );
+  }
+
+  KIO::filesize_t getSize() {
+    return fileSize;
+  }
+  
+private:
+  KIO::filesize_t fileSize;
+  QString _foundText;
+};
+
 #endif
