@@ -35,6 +35,8 @@
 #include <sys/stat.h>
 // Qt includes
 #include <qdatetime.h>
+// KDE includes
+#include <kmimetype.h>
 // Krusader includes
 #include "vfile.h"
 #include "krpermhandler.h"
@@ -64,7 +66,7 @@ vfile::vfile(const QString& name,	                  // useful construtor
 	vfile_mimeType=mime;
 	vfile_symDest=symDest;
 	vfile_mode=mode;
-	if (vfile_isDir())
+	if (vfile_isDir() && !vfile_symLink )
 		vfile_size = 0;
 }
 
@@ -92,29 +94,37 @@ vfile::vfile(const QString& name,	                  // useful construtor
 	vfile_mimeType=mime;
 	vfile_symDest=symDest;
 	vfile_mode=mode;
-	if (vfile_isDir())
+	if ( vfile_isDir() && !vfile_symLink )
 		vfile_size = 0;
 }
 
 char vfile::vfile_isReadable() const {
-	if( vfile_userName.isEmpty() )
+	if( vfile_userName.isNull() )
 		return KRpermHandler::readable(vfile_perm,vfile_groupId,vfile_ownerId);
 	else
-		return KRpermHandler::ftpReadable(vfile_userName, vfile_owner, vfile_perm);
+		return KRpermHandler::ftpReadable(vfile_owner, vfile_userName, vfile_perm);
 }
 
 char vfile::vfile_isWriteable() const {
-	if( vfile_userName.isEmpty() )
+	if( vfile_userName.isNull() )
 		return KRpermHandler::writeable(vfile_perm,vfile_groupId,vfile_ownerId);
 	else
-		return KRpermHandler::ftpWriteable(vfile_userName, vfile_owner, vfile_perm);
+		return KRpermHandler::ftpWriteable(vfile_owner, vfile_userName, vfile_perm);
 }
 
 char vfile::vfile_isExecutable() const {
-	if( vfile_userName.isEmpty() )
+	if( vfile_userName.isNull() )
 		return KRpermHandler::executable(vfile_perm,vfile_groupId,vfile_ownerId);
 	else
-		return KRpermHandler::ftpExecutable(vfile_userName, vfile_owner, vfile_perm);
+		return KRpermHandler::ftpExecutable(vfile_owner, vfile_userName, vfile_perm);
+}
+
+const QString& vfile::vfile_getMime(bool fast){
+	if( vfile_mimeType == QString::null ){ // mimetype == "" is OK so don't check mimetype.empty() !
+		vfile_mimeType = KMimeType::findByURL( vfile_getUrl(),vfile_getMode(),vfile_getUrl().isLocalFile(),fast)->name();
+		if( vfile_mimeType.contains("directory") ) vfile_perm[0] = 'd';
+	}
+	return vfile_mimeType;
 }
 
 const QString& vfile::vfile_getOwner(){
