@@ -48,6 +48,7 @@
 #include <KViewer/krviewer.h>
 
 #ifdef __KJSEMBED__
+#include "KrJS/krjs.h"
 #include <kjsembed/jsconsolewidget.h>
 #endif
 
@@ -57,6 +58,8 @@
 #include "krusaderview.h"
 #include "Panel/listpanel.h"
 #include "Panel/krselectionmode.h"
+#include "Panel/krdetailedviewitem.h"
+#include "Panel/krbriefviewitem.h"
 #include "Dialogs/krdialogs.h"
 #include "Dialogs/krspwidgets.h"
 #include "GUI/krusaderstatus.h"
@@ -140,11 +143,8 @@ void KRslots::compareContent() {
   }
   else  {
     // if we got here, then we can't be sure what file to diff
-    KMessageBox::detailedError(0,i18n("Don't know which files to compare."),
-      i18n("To compare 2 files by content, you can either\n"
-    "- select (mark) one file in the left panel, and one in the right panel\n"
-    "- select exactly two files in the active panel\n"
-    "- make sure there is a file in the other panel, with the same name as the current file in the active panel"));
+    KMessageBox::detailedError(0, i18n("Don't know which files to compare."), "<qt>" + i18n("To compare two files by content, you can either:<ul><li>Select one file in the left panel, and one in the right panel.</li><li>Select exactly two files in the active panel.</li><li>Make sure there is a file in the other panel, with the same name as the current file in the active panel.</li></ul>") + "</qt>" );
+
     return;
   }
 
@@ -300,6 +300,8 @@ void KRslots::newFTPconnection(){ ACTIVE_FUNC->newFTPconnection();           }
 void KRslots::cut()             { ACTIVE_FUNC->copyToClipboard( true );      }
 void KRslots::copy()            { ACTIVE_FUNC->copyToClipboard( false );     }
 void KRslots::paste()           { ACTIVE_FUNC->pasteFromClipboard();         }
+void KRslots::createChecksum()  { ACTIVE_FUNC->createChecksum(); }
+void KRslots::matchChecksum()  { ACTIVE_FUNC->matchChecksum(); }
 
 // run external modules / programs
 void KRslots::runKonfigurator(bool firstTime) {
@@ -314,6 +316,9 @@ void KRslots::runKonfigurator(bool firstTime) {
     krConfig->setGroup( "Look&Feel" );
     if((krConfig->readEntry("Filelist Icon Size",_FilelistIconSize)).toInt() != size )
       QPixmapCache::clear();
+      
+    KrDetailedViewItem::itemHeightChanged(); // needed when icon size / font size changes
+	 KrBriefViewItem::itemHeightChanged();
 
     MAIN_VIEW->leftMng->slotRecreatePanels();
     MAIN_VIEW->rightMng->slotRecreatePanels();
@@ -326,10 +331,12 @@ void KRslots::runKonfigurator(bool firstTime) {
 
 void KRslots::toggleHidden(){
   krConfig->setGroup("Look&Feel");
-	bool show = !krConfig->readBoolEntry("Show Hidden",_ShowHidden);
-	krApp->actToggleHidden->setChecked(show);
+  bool show = !krConfig->readBoolEntry("Show Hidden",_ShowHidden);
+  krApp->actToggleHidden->setChecked(show);
   krConfig->writeEntry("Show Hidden",show);
-	REFRESH_BOTH_PANELS;
+
+  MAIN_VIEW->leftMng->refreshAllTabs( true );
+  MAIN_VIEW->rightMng->refreshAllTabs( true );
 }
 
 void KRslots::toggleSwapPanels(){
@@ -362,7 +369,17 @@ void KRslots::toggleSwapPanels(){
 }
 
 void KRslots::search() {
-  new KrSearchDialog();
+	if ( KrSearchDialog::SearchDialog != 0 ) {
+		krConfig->setGroup( "Search" );
+		if( krConfig->readBoolEntry( "Window Maximized",  false ) )
+	KrSearchDialog::SearchDialog->showMaximized();
+		else
+			KrSearchDialog::SearchDialog->showNormal();
+	
+		KrSearchDialog::SearchDialog->raise();
+		KrSearchDialog::SearchDialog->setActiveWindow();
+	} else
+		KrSearchDialog::SearchDialog = new KrSearchDialog();
 }
 
 void KRslots::locate()
@@ -539,7 +556,7 @@ void KRslots::editDlg(){
 	KURL dest = KChooseDir::getDir(i18n("Enter the filename to edit:"), ACTIVE_PANEL->virtualPath(), ACTIVE_PANEL->virtualPath());
 	if ( dest.isEmpty() ) return ; // the user canceled
 
-    KrViewer::edit( dest, true );
+    KrViewer::edit( dest );
     
     if( dest.upURL().equals( ACTIVE_PANEL->virtualPath(), true ) )
       refresh();
@@ -567,7 +584,11 @@ void KRslots::previousTab() {
 void KRslots::newTab(QListViewItem *item) {
   if (!item) return;
   KrViewItem *it = dynamic_cast<KrViewItem*>(item);
-  if (it->isDir()) {
+  if( it->name() == ".." ) {
+    KURL url = ACTIVE_PANEL->virtualPath();
+    ACTIVE_PANEL_MANAGER->slotNewTab( url.upURL() );
+  }
+  else if (ITEM2VFILE(ACTIVE_PANEL, it)->vfile_isDir()) {
     KURL url = ACTIVE_PANEL->virtualPath();
     url.addPath( it->name() );
     ACTIVE_PANEL_MANAGER->slotNewTab( url );
@@ -754,10 +775,10 @@ void KRslots::manageUseractions() {
    Konfigurator konfigurator( false, 7 ); // page 7 are the UserActions
 }
 
-void KRslots::slotSynchronizeDirs() {
+void KRslots::slotSynchronizeDirs( QStringList selected ) {
   SynchronizerGUI *sync = new SynchronizerGUI( krApp,
                 MAIN_VIEW->left->func->files()->vfs_getOrigin().prettyURL(0,KURL::StripFileProtocol),
-                MAIN_VIEW->right->func->files()->vfs_getOrigin().prettyURL(0,KURL::StripFileProtocol) );
+                MAIN_VIEW->right->func->files()->vfs_getOrigin().prettyURL(0,KURL::StripFileProtocol), selected );
 
   bool refresh = sync->wasSynchronization();
   delete sync;
@@ -826,11 +847,30 @@ void KRslots::windowInactive() {
 	MAIN_VIEW->right->panelInactive();
 }
 
+void KRslots::slotLocationBar() {
+	ACTIVE_PANEL->origin->lineEdit()->selectAll();
+	ACTIVE_PANEL->origin->setFocus();
+}
+
+void KRslots::slotJumpBack() {
+	ACTIVE_PANEL->jumpBack();
+}
+
+void KRslots::slotSetJumpBack() {
+	ACTIVE_PANEL->setJumpBack( ACTIVE_PANEL->virtualPath() );
+}
+
 //shows the JavaScript-Console
 void KRslots::jsConsole() {
 #ifdef __KJSEMBED__
+    if ( ! krJS )
+        krJS = new KrJS();
     krJS->view()->show();
 #endif
 }
 
+void KRslots::bookmarkCurrent() {
+	krBookMan->bookmarkCurrent(ACTIVE_PANEL->virtualPath());
+}
+
 #include "krslots.moc"
