@@ -50,11 +50,6 @@ QWidget( parent, "PanelManager" ), _layout( 0 ), _left( left ), _self( self ), _
 
    if ( HIDE_ON_SINGLE_TAB ) HIDE
       else SHOW
-		
-#ifdef __KJSEMBED__
-   // make this object available for scripting
-   krApp->js->addObject( this, "PanelManager" );
-#endif
 }
 
 void PanelManager::slotChangePanel( ListPanel *p ) {
@@ -158,7 +153,7 @@ void PanelManager::slotCloseTab() {
    _self = _tabbar->removeCurrentPanel( oldp );
    _stack->raiseWidget( _self );
    _stack->removeWidget( oldp );
-   delete oldp;
+   deletePanel( oldp );
 
    // setup pointers
    _self->otherPanel = _other;
@@ -192,7 +187,7 @@ void PanelManager::slotCloseTab( int index ) {
       _tabbar->removeTab( t );
 
       _stack->removeWidget( oldp );
-      delete oldp;      
+      deletePanel( oldp );
    }
 
    if ( _tabbar->count() == 1 ) 
@@ -256,7 +251,7 @@ void PanelManager::slotRecreatePanels() {
        _other->otherPanel = newPanel;         
      updatedPanel->panel = newPanel;
      newPanel->start( oldPanel->virtualPath(), true );          
-     delete oldPanel;
+     deletePanel( oldPanel );
    
      _tabbar->updateTab( newPanel );
    }
@@ -281,4 +276,29 @@ void PanelManager::slotPreviousTab() {
 	slotChangePanel(nextp);   
 }
 
+void PanelManager::refreshAllTabs( bool invalidate ) {
+   int i=0;
+   while (i < _tabbar->count()) {
+      PanelTab *t = dynamic_cast<PanelTab*>(_tabbar->tabAt(i));
+      if (t && t->panel && t->panel->func ) {
+         vfs * vfs = t->panel->func->files();
+         if( vfs ) {
+            if( invalidate )
+               vfs->vfs_invalidate();
+            vfs->vfs_refresh();
+         }
+      }
+      ++i;
+   }
+}
+
+void PanelManager::deletePanel( ListPanel * p ) {
+  if( p && p->func && p->func->files() && !p->func->files()->vfs_canDelete() ) {
+    connect( p->func->files(), SIGNAL( deleteAllowed() ), p, SLOT( deleteLater() ) );
+    p->func->files()->vfs_requestDelete();
+    return;
+  }
+  delete p;
+}
+
 #include "panelmanager.moc"
